==> trade-center-biz-0.2.2-ZDX-20161103.125609-1-sources.jar: cn/com/duiba/order/center/biz/handle/ActivityOrderHandle.java <==
package cn.com.duiba.order.center.biz.handle;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import cn.com.duiba.idmaker.service.api.enums.IDMakerTypeEnums;
import cn.com.duiba.idmaker.service.api.remoteservice.RemoteIDMakerService;
import cn.com.duiba.order.center.api.dto.ActivityOrderDto;
import cn.com.duiba.order.center.biz.dao.BaseActivityOrderDaoTool;
import cn.com.duiba.order.center.biz.dao.activity.ActivityOrderDao;
import cn.com.duiba.order.center.biz.dao.activityhouse.ActivityOrderHouseDao;
import cn.com.duiba.order.center.biz.entity.ActivityOrderEntity;
import cn.com.duiba.wolf.dubbo.DubboResult;

@Component
public class ActivityOrderHandle {

	@Resource
	private RemoteIDMakerService remoteIDMakerService;
	
	@Autowired
	private ActivityOrderDao activityOrderDao;
	@Autowired
	private ActivityOrderHouseDao activityOrderHouseDao;
	

	public void insert(ActivityOrderEntity entity) {
		//TODO ID生成器类型
		DubboResult<Long> ret = remoteIDMakerService.getNextID(IDMakerTypeEnums.ACTIVITY_ORDER.getType());
		if (!ret.isSuccess()) {
			throw new RuntimeException("ID生成失败");
		}
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(entity.getConsumerId());
		String orderNum = ret.getResult() + "" + suffix;
		entity.setSuffix(suffix);
		System.out.println("suffix="+suffix);
		entity.setOrderNum(orderNum);
		activityOrderDao.insert(entity);
	}

	public ActivityOrderEntity find(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.find(suffix,orderNum);
	}

	public int updateCreditsSuccess(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateCreditsSuccess(suffix,orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId,ActivityOrderDto.ConsumeCreditsSuccess);
	}
	
	public int updateCreditsSuccessDowngrade(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateCreditsSuccessDowngrade(suffix,orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId,ActivityOrderDto.ConsumeCreditsSuccess);
	}

	public int updateCreditsFail(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId, String error4admin, String error4developer, String error4consumer) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateCreditsFail(suffix, orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId, error4admin, error4developer, error4consumer, ActivityOrderDto.ConsumeCreditsFail);
	}
	
	public int updateAddCreditsSuccess(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateAddCreditsSuccess(suffix, orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId, ActivityOrderDto.AddCreditsSuccess);
	}

	public int updateAddCreditsFail(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId, String error4admin, String error4developer, String error4consumer) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateAddCreditsFail(suffix, orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId, error4admin, error4developer, error4consumer, ActivityOrderDto.AddCreditsFail);
	}

	public int updateExchangeStatusWait(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateExchangeStatus(suffix, orderNum, ActivityOrderDto.ExchangeWait);
	}

	public int updateExchangeStatusSuccess(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateExchangeStatus(suffix, orderNum, ActivityOrderDto.ExchangeSuccess);
	}

	public int updateExchangeStatusFail(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateExchangeStatus(suffix, orderNum, ActivityOrderDto.ExchangeFail);
	}

	public int updateExchangeStatusOverdue(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateExchangeStatus(suffix, orderNum, ActivityOrderDto.ExchangeOverdue);
	}

	public int updateDeveloperBizId(String orderNum, String bizId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateDeveloperBizId(suffix,orderNum, bizId);
	}
	
	public int updateAddDeveloperBizId(String orderNum, String bizId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateAddDeveloperBizId(suffix,orderNum, bizId);
	}

	public int updateMainOrderNum(String orderNum, String mainOrderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateMainOrderNum(suffix, orderNum, mainOrderNum);
	}

	public int countConsumerJoinNum(long consumerId, long duibaActivityId, String activityType) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.countConsumerJoinNum(suffix, consumerId, duibaActivityId, activityType);
	}

	public List<ActivityOrderEntity> findConsumerJoinList(long consumerId, List<Long> duibaActivityIds, String activityType) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.findConsumerJoinList(suffix, consumerId, duibaActivityIds, activityType);
	}

	public List<ActivityOrderEntity> findByOrderNums(long consumerId, List<String> orderNums) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.findByOrderNums(suffix, orderNums);
	}
	
	public List<Long> findOptionIds(Long consumerId, Long appId, String activityType){
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.findOptionIds(consumerId, appId, activityType, suffix);
	}
	
	public List<String> findByExpirationTime(String expirationTime,String activityType){
		return activityOrderHouseDao.findByExpirationTime(expirationTime,activityType);
	}
	
	public List<Long> findOptionIdsHouse(Long consumerId, Long appId, String activityType){
		return activityOrderHouseDao.findOptionIds(consumerId, appId, activityType);
	}
}

==> trade-center-biz-0.2.7-ZDX-20161114.122234-1-sources.jar: cn/com/duiba/order/center/biz/handle/ActivityOrderHandle.java <==
package cn.com.duiba.order.center.biz.handle;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import cn.com.duiba.idmaker.service.api.enums.IDMakerTypeEnums;
import cn.com.duiba.idmaker.service.api.remoteservice.RemoteIDMakerService;
import cn.com.duiba.order.center.api.dto.ActivityOrderDto;
import cn.com.duiba.order.center.biz.dao.BaseActivityOrderDaoTool;
import cn.com.duiba.order.center.biz.dao.activity.ActivityOrderDao;
import cn.com.duiba.order.center.biz.dao.activityhouse.ActivityOrderHouseDao;
import cn.com.duiba.order.center.biz.entity.ActivityOrderEntity;
import cn.com.duiba.wolf.dubbo.DubboResult;

@Component
public class ActivityOrderHandle {

	@Resource
	private RemoteIDMakerService remoteIDMakerService;
	
	@Autowired
	private ActivityOrderDao activityOrderDao;
	@Autowired
	private ActivityOrderHouseDao activityOrderHouseDao;
	

	public void insert(ActivityOrderEntity entity) {
		//TODO ID生成器类型
		DubboResult<Long> ret = remoteIDMakerService.getNextID(IDMakerTypeEnums.ACTIVITY_ORDER.getType());
		if (!ret.isSuccess()) {
			throw new RuntimeException("ID生成失败");
		}
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(entity.getConsumerId());
		String orderNum = ret.getResult() + "" + suffix;
		entity.setSuffix(suffix);
		System.out.println("suffix="+suffix);
		entity.setOrderNum(orderNum);
		activityOrderDao.insert(entity);
	}

	public ActivityOrderEntity find(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.find(suffix,orderNum);
	}

	public int updateCreditsSuccess(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateCreditsSuccess(suffix,orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId,ActivityOrderDto.ConsumeCreditsSuccess);
	}
	
	public int updateCreditsSuccessDowngrade(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateCreditsSuccessDowngrade(suffix,orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId,ActivityOrderDto.ConsumeCreditsSuccess);
	}

	public int updateCreditsFail(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId, String error4admin, String error4developer, String error4consumer) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		error4admin = StringUtils.substring(error4admin, 0, 200);
		error4developer = StringUtils.substring(error4developer, 0, 200);
		error4consumer = StringUtils.substring(error4consumer, 0, 200);
		return activityOrderDao.updateCreditsFail(suffix, orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId, error4admin, error4developer, error4consumer, ActivityOrderDto.ConsumeCreditsFail);
	}
	
	public int updateAddCreditsSuccess(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateAddCreditsSuccess(suffix, orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId, ActivityOrderDto.AddCreditsSuccess);
	}

	public int updateAddCreditsFail(String orderNum, Long activityOptionId, String activityOptionName, String activityOptionType, String activityOptionFacePrice, Long appItemId, Long itemId, Long gid, String gtype, Long couponId, String error4admin, String error4developer, String error4consumer) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		error4admin = StringUtils.substring(error4admin, 0, 200);
		error4developer = StringUtils.substring(error4developer, 0, 200);
		error4consumer = StringUtils.substring(error4consumer, 0, 200);
		return activityOrderDao.updateAddCreditsFail(suffix, orderNum, activityOptionId, activityOptionName, activityOptionType, activityOptionFacePrice, appItemId, itemId, gid, gtype, couponId, error4admin, error4developer, error4consumer, ActivityOrderDto.AddCreditsFail);
	}
	
	public int addCreditsStatusToProcessing(String orderNum){
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.addCreditsStatusToProcessing(suffix, orderNum, ActivityOrderDto.AddCreditsProcessing);
	}

	public int updateExchangeStatusWait(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateExchangeStatus(suffix, orderNum, ActivityOrderDto.ExchangeWait);
	}

	public int updateExchangeStatusSuccess(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateExchangeStatus(suffix, orderNum, ActivityOrderDto.ExchangeSuccess);
	}

	public int updateExchangeStatusFail(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateExchangeStatus(suffix, orderNum, ActivityOrderDto.ExchangeFail);
	}

	public int updateExchangeStatusOverdue(String orderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateExchangeStatus(suffix, orderNum, ActivityOrderDto.ExchangeOverdue);
	}

	public int updateDeveloperBizId(String orderNum, String bizId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateDeveloperBizId(suffix,orderNum, bizId);
	}
	
	public int updateAddDeveloperBizId(String orderNum, String bizId) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateAddDeveloperBizId(suffix,orderNum, bizId);
	}

	public int updateMainOrderNum(String orderNum, String mainOrderNum) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateMainOrderNum(suffix, orderNum, mainOrderNum);
	}

	public int countConsumerJoinNum(long consumerId, long duibaActivityId, String activityType) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.countConsumerJoinNum(suffix, consumerId, duibaActivityId, activityType);
	}

	public List<ActivityOrderEntity> findConsumerJoinList(long consumerId, List<Long> duibaActivityIds, String activityType) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.findConsumerJoinList(suffix, consumerId, duibaActivityIds, activityType);
	}
	
	public ActivityOrderEntity findConsumerDuibaActivity4day(long consumerId, Long duibaActivityId, String activityType,
			String start, String end){
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.findConsumerDuibaActivity4day(suffix,consumerId, duibaActivityId, activityType, start, end);
	}

	public List<ActivityOrderEntity> findByOrderNums(long consumerId, List<String> orderNums) {
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.findByOrderNums(suffix, orderNums);
	}
	
	public List<Long> findOptionIds(Long consumerId, Long appId, String activityType){
		String suffix = BaseActivityOrderDaoTool.getTableSuffix(consumerId);
		return activityOrderDao.findOptionIds(consumerId, appId, activityType, suffix);
	}
	
	public int updateAddCredits(String orderNum, Long credits){
		String suffix = BaseActivityOrderDaoTool.getTableSuffixByOrderNum(orderNum);
		return activityOrderDao.updateAddCredits(suffix, orderNum, credits);
	}
	
	public List<String> findByExpirationTime(String expirationTime,String activityType){
		return activityOrderHouseDao.findByExpirationTime(expirationTime,activityType);
	}
	
	public List<Long> findOptionIdsHouse(Long consumerId, Long appId, String activityType){
		return activityOrderHouseDao.findOptionIds(consumerId, appId, activityType);
	}
	
	public List<ActivityOrderEntity> findByAppIdWithPage(Map<String, Object> queryMap) {
		return activityOrderHouseDao.findByAppIdWithPage(queryMap);
	}
	
	public int getCountByAppId(Map<String, Object> queryMap) {
		return activityOrderHouseDao.getCountByAppId(queryMap);
	}
	
	public List<Map<String,Long>> findFailByActivity4App(List<Long> activityIds, Long appId) {
		return activityOrderHouseDao.findFailByActivity4App(activityIds, appId);
	}
}
